==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-honeycode/include/aws/honeycode/model/ImportDataSourceConfig.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/honeycode/Honeycode_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace Honeycode
{
namespace Model
{

  /**
   * <p> An object that contains the configuration parameters for the data source of
   * an import request. </p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/honeycode-2020-03-01/ImportDataSourceConfig">AWS
   * API Reference</a></p>
   */
  class AWS_HONEYCODE_API ImportDataSourceConfig
  {
  public:
    ImportDataSourceConfig();
    ImportDataSourceConfig(Aws::Utils::Json::JsonView jsonValue);
    ImportDataSourceConfig& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline const Aws::String& GetDataSourceUrl() const{ return m_dataSourceUrl; }

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline bool DataSourceUrlHasBeenSet() const { return m_dataSourceUrlHasBeenSet; }

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline void SetDataSourceUrl(const Aws::String& value) { m_dataSourceUrlHasBeenSet = true; m_dataSourceUrl = value; }

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline void SetDataSourceUrl(Aws::String&& value) { m_dataSourceUrlHasBeenSet = true; m_dataSourceUrl = std::move(value); }

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline void SetDataSourceUrl(const char* value) { m_dataSourceUrlHasBeenSet = true; m_dataSourceUrl.assign(value); }

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline ImportDataSourceConfig& WithDataSourceUrl(const Aws::String& value) { SetDataSourceUrl(value); return *this;}

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline ImportDataSourceConfig& WithDataSourceUrl(Aws::String&& value) { SetDataSourceUrl(std::move(value)); return *this;}

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline ImportDataSourceConfig& WithDataSourceUrl(const char* value) { SetDataSourceUrl(value); return *this;}

  private:

    Aws::String m_dataSourceUrl;
    bool m_dataSourceUrlHasBeenSet;
  };

} // namespace Model
} // namespace Honeycode
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-honeycode/include/aws/honeycode/model/ImportDataSourceConfig.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/honeycode/Honeycode_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace Honeycode
{
namespace Model
{

  /**
   * <p> An object that contains the configuration parameters for the data source of
   * an import request. </p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/honeycode-2020-03-01/ImportDataSourceConfig">AWS
   * API Reference</a></p>
   */
  class AWS_HONEYCODE_API ImportDataSourceConfig
  {
  public:
    ImportDataSourceConfig();
    ImportDataSourceConfig(Aws::Utils::Json::JsonView jsonValue);
    ImportDataSourceConfig& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline const Aws::String& GetDataSourceUrl() const{ return m_dataSourceUrl; }

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline bool DataSourceUrlHasBeenSet() const { return m_dataSourceUrlHasBeenSet; }

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline void SetDataSourceUrl(const Aws::String& value) { m_dataSourceUrlHasBeenSet = true; m_dataSourceUrl = value; }

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline void SetDataSourceUrl(Aws::String&& value) { m_dataSourceUrlHasBeenSet = true; m_dataSourceUrl = std::move(value); }

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline void SetDataSourceUrl(const char* value) { m_dataSourceUrlHasBeenSet = true; m_dataSourceUrl.assign(value); }

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline ImportDataSourceConfig& WithDataSourceUrl(const Aws::String& value) { SetDataSourceUrl(value); return *this;}

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline ImportDataSourceConfig& WithDataSourceUrl(Aws::String&& value) { SetDataSourceUrl(std::move(value)); return *this;}

    /**
     * <p> The URL from which source data will be downloaded for the import request.
     * </p>
     */
    inline ImportDataSourceConfig& WithDataSourceUrl(const char* value) { SetDataSourceUrl(value); return *this;}

  private:

    Aws::String m_dataSourceUrl;
    bool m_dataSourceUrlHasBeenSet = false;
  };

} // namespace Model
} // namespace Honeycode
} // namespace Aws
